@@ -24,11 +24,12 @@
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 258 2007-07-06 12:03:11Z CodyPrecord $"
-__revision__ = "$Revision: 258 $"
+__svnid__ = "$Id: dev_tool.py 318 2007-07-23 09:42:33Z CodyPrecord $"
+__revision__ = "$Revision: 318 $"
 
 import os
 import sys
+import platform
 import traceback
 import codecs
 import time
@@ -54,7 +55,7 @@ def DEBUGP(statement, mode="std", log_lvl="none"):
        
     """
     # Turn off normal debugging messages when not in Debug mode
-    if mode == "std" and not 'DEBUG' in ed_glob.PROFILE['MODE']:
+    if mode == "std" and not ed_glob.DEBUG:
         return 0
 
     # Build time string for tstamp
@@ -70,7 +71,6 @@ def DEBUGP(statement, mode="std", log_lvl="none"):
         for line in s_lst:
             out = u"%s %s" % (now, line)
             print out.encode('utf-8', 'replace')
-        return 0
     elif mode == "log":
         logfile = os.environ.get('EDITRA_LOG')
         if logfile is None or not os.path.exists(logfile):
@@ -84,11 +84,9 @@ def DEBUGP(statement, mode="std", log_lvl="none"):
         else:
             writer.write(u"MSG: %s\n" % statement)
         file_handle.close()
-        return 0	
     else:
         print u"Improper DEBUG MODE: Defaulting to stdout"
         print statement
-        return 1
 
 def EnvironmentInfo():
     """Returns a string of the systems information
@@ -99,14 +97,29 @@ def EnvironmentInfo():
     info.append("#---- System Information ----#")
     info.append("%s Version: %s" % (ed_glob.prog_name, ed_glob.version))
     info.append("Operating System: %s" % wx.GetOsDescription())
+    if sys.platform == 'darwin':
+        info.append("Mac OSX: %s" % platform.mac_ver()[0])
     info.append("Python Version: %s" % sys.version)
     info.append("wxPython Version: %s" % wx.version())
-    info.append("wxPython Info: %s" % "\n\t\t\t".join(wx.PlatformInfo))
+    info.append("wxPython Info: %s" % "\n\t\t".join(wx.PlatformInfo))
     info.append("Python Encoding: Default=%s  File=%s" % \
                 (sys.getdefaultencoding(), sys.getfilesystemencoding()))
     info.append("wxPython Encoding: %s" % wx.GetDefaultPyEncoding())
-    info.append("Frozen: %s" % str(hasattr(sys, 'frozen')))
+    info.append("System Architecture: %s %s" % (platform.architecture()[0], \
+                                                platform.machine()))
+    info.append("Byte order: %s" % sys.byteorder)
+    info.append("Frozen: %s" % str(getattr(sys, 'frozen', 'False')))
     info.append("#---- End System Information ----#")
+    info.append("#---- Runtime Variables ----#")
+    from profiler import Profile
+    for key, val in Profile().iteritems():
+        # Exclude "private" information
+        if key.startswith('FILE') or key == 'MYPROFILE':
+            continue
+        else:
+            info.append("%s=%s" % (key, str(val)))
+    info.append("#---- End Runtime Variables ----#")
+
     return "\n".join(info)
 
 def ExceptionHook(exctype, value, trace):
@@ -288,3 +301,5 @@ class ErrorDialog(wx.Dialog):
 
         """
         self.Destroy()
+        evt.Skip()
+
