@@ -36,12 +36,34 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 288 2007-07-12 11:48:55Z CodyPrecord $"
-__revision__ = "$Revision: 288 $"
+__svnid__ = "$Id: ed_glob.py 321 2007-07-25 07:04:48Z CodyPrecord $"
+__revision__ = "$Revision: 321 $"
+
+__all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'version', 'prog_name',
+            'ID_NEW', 'ID_OPEN', 'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 
+            'ID_SAVEAS', 'ID_SAVEALL', 'ID_SAVE_PROFILE', 'ID_LOAD_PROFILE', 
+            'ID_PRINT', 'ID_PRINT_PRE', 'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO', 
+            'ID_REDO', 'ID_CUT', 'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 
+            'ID_ADD_BM', 'ID_DEL_BM',  'ID_DEL_ALL_BM', 'ID_LINE_AFTER', 
+            'ID_LINE_BEFORE', 'ID_CUT_LINE', 'ID_COPY_LINE', 'ID_JOIN_LINES', 
+            'ID_TRANSPOSE', 'ID_FIND', 'ID_FIND_REPLACE', 'ID_QUICK_FIND', 
+            'ID_PREF', 'ID_ZOOM_OUT', 'home_page', 'contact_mail',
+            'ID_ZOOM_IN', 'ID_ZOOM_NORMAL', 'ID_SHOW_EDGE', 'ID_SHOW_EOL',
+            'ID_SHOW_LN', 'ID_SHOW_WS', 'ID_PERSPECTIVES', 'ID_INDENT_GUIDES', 
+            'ID_VIEW_TOOL', 'ID_GOTO_LINE', 'ID_NEXT_MARK', 'ID_PRE_MARK', 
+            'ID_FONT', 'ID_EOL_MODE', 'ID_EOL_MAC', 'ID_EOL_UNIX', 'ID_EOL_WIN',
+            'ID_WORD_WRAP', 'ID_INDENT',  'ID_UNINDENT', 'ID_TO_UPPER', 
+            'ID_TO_LOWER', 'ID_SPACE_TO_TAB', 'ID_TAB_TO_SPACE', 'ID_TRIM_WS', 
+            'ID_COMMENT', 'ID_UNCOMMENT', 'ID_AUTOCOMP', 'ID_AUTOINDENT', 
+            'ID_SYNTAX', 'ID_FOLDING', 'ID_BRACKETHL', 'ID_LEXER', 
+            'ID_KWHELPER', 'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 
+            'ID_MACRO_STOP', 'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 
+            'ID_CONTACT', 'ID_COMMAND_BAR' 
+]
 
 #---- Project Info ----#
 Author = __Author__  = u'Cody Precord'
-version = __version__ = u'0.1.50'
+version = __version__ = u'0.1.64'
 prog_name = u'Editra'
 home_page = u"http://editra.org"
 contact_mail = u"staff@editra.org"
@@ -66,6 +88,8 @@ CONFIG = {
           'TEST_DIR'    : "",   # Test data files dir
 }
 
+DEBUG = False
+
 #---- Object ID's ----#
 # File Menu IDs
 ID_NEW           = wx.ID_NEW
@@ -103,6 +127,11 @@ ID_JOIN_LINES    = wx.NewId()
 ID_TRANSPOSE     = wx.NewId()
 ID_FIND          = wx.ID_FIND
 ID_FIND_REPLACE  = wx.ID_REPLACE
+# Using the system ids automatically disables the menus items
+# when the dialog is open which is not wanted
+if wx.Platform == '__WXMAC__':
+    ID_FIND = wx.NewId()
+    ID_FIND_REPLACE = wx.NewId()
 ID_QUICK_FIND    = wx.NewId()
 ID_PREF          = wx.ID_PREFERENCES
 
@@ -201,6 +230,7 @@ ID_HARDDISK          = wx.NewId()
 ID_PLUGIN_CFG        = wx.NewId()
 ID_PLUGIN_DL         = wx.NewId()
 ID_PLUGIN_INST       = wx.NewId()
+ID_REPORTER          = wx.NewId()
 ID_USB               = wx.NewId()
 ID_PREF_ADVANCED     = wx.NewId()
 ID_PREF_APPEARANCE   = wx.NewId()
@@ -214,47 +244,6 @@ SB_ROWCOL        = 1
 
 #---- Objects ----#
 
-# Dictionary to hold the profile
-# Always holds default settings incase profile loading fails or file
-# is incorrecly formatted/missing values
-PROFILE = {
-           'ALPHA'      : 255,              # Transparency level
-           'AALIASING'  : True,             # Use Anti-Aliasing if availble
-           'APPSPLASH'  : True,             # Show splash at startup
-           'AUTO_COMP'  : True,             # Use Auto-comp if available
-           'AUTO_INDENT': True,             # Use Auto Indent
-           'BRACKETHL'  : True,             # Use bracket highlighting
-           'CHECKMOD'   : True,             # Auto check file for file mod
-           'CODE_FOLD'  : True,             # Use code folding
-           'DEFAULT'    : False,            # No longer used I believe
-           'DEFAULT_VIEW' : 'Default',      # Default Perspective
-           'EDGE'       : 80,               # Edge guide column
-           'EOL'        : 'Unix (\\n)',     # EOL mode
-           'FHIST_LVL'  : 5,                # Filehistory length (9 is max)
-           'GUIDES'     : True,             # Use Indentation guides
-           'ICONS'      : 'Nuovo',          # Icon Theme
-           'ICON_SZ'    : (24,24),          # Toolbar Icon Size
-           'LANG'       : 'Default',        # UI language
-           'MODE'       : 'CODE',           # Overall editor mode
-           'MYPROFILE'  : 'default.pp',     # Path to profile file
-           'PRINT_MODE' : 'BLACK/WHITE',    # Printer rendering mode
-           'SAVE_POS'   : True,             # Remember Carat positions
-           'SHOW_EDGE'  : True,             # Show Edge Guide
-           'SHOW_EOL'   : False,            # Show EOL markers
-           'SHOW_LN'    : True,             # Show Line Numbers
-           'SYNTAX'     : True,             # Use Syntax Highlighting
-           'SYNTHEME'   : 'Default',        # Syntax Highlight color scheme
-           'TABWIDTH'   : 8,                # Tab width
-           'THEME'      : 'DEFAULT',        # For future use
-           'TOOLBAR'    : True,             # Show Toolbar
-           'USETABS'    : True,             # Use tabs instead of spaces
-           'SHOW_WS'    : False,            # Show whitespace markers
-           'WRAP'       : True,             # Use Wordwrap
-           'SET_WSIZE'  : True,             # Remember mainwindow size on exit
-           'WSIZE'      : (700, 450),       # Mainwindow size
-           'SET_WPOS'   : True              # Remember window position
-}
-
 # Dictionary to map object ids to Profile keys
 ID_2_PROF = {
              ID_PREF_AALIAS       : 'AALIASING',
@@ -270,6 +259,7 @@ ID_2_PROF = {
              ID_PREF_FHIST        : 'FHIST_LVL',
              ID_INDENT_GUIDES     : 'GUIDES',
              ID_PREF_LANG         : 'LANG',
+             ID_REPORTER          : 'REPORTER',
              ID_SYNTAX            : 'SYNTAX',
              ID_PREF_SYNTHEME     : 'SYNTHEME',
              ID_PREF_TABS         : 'USETABS',
