@@ -50,8 +50,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 282 2007-07-11 09:27:53Z CodyPrecord $"
-__revision__ = "$Revision: 282 $"
+__svnid__ = "$Id: ed_main.py 319 2007-07-23 13:26:58Z CodyPrecord $"
+__revision__ = "$Revision: 319 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -63,6 +63,8 @@ import wx
 import wx.aui
 from ed_glob import *
 import util
+from profiler import Profile_Get as _PGET
+from profiler import Profile_Set as _PSET
 import profiler
 import ed_toolbar
 import ed_pages
@@ -105,15 +107,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         util.SetWindowIcon(self)
 
         # Check if user wants Metal Style under OS X
-        if wx.Platform == '__WXMAC__' and PROFILE.has_key('METAL'):
-            if PROFILE['METAL']:
-                self.SetExtraStyle(wx.FRAME_EX_METAL)
+        if wx.Platform == '__WXMAC__' and _PGET('METAL'):
+            self.SetExtraStyle(wx.FRAME_EX_METAL)
 
         #---- Sizers to hold subapplets ----#
         self.sizer = wx.BoxSizer(wx.VERTICAL)
 
         #---- Setup File History ----#
-        self.filehistory = wx.FileHistory(int(PROFILE['FHIST_LVL']))
+        self.filehistory = wx.FileHistory(_PGET('FHIST_LVL', 'int', 5))
 
         #---- Toolbar ----#
         self.toolbar = None
@@ -144,7 +145,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         #---- End Statusbar Setup ----#
 
         #---- Create a toolbar ----#
-        if PROFILE['TOOLBAR']:
+        if _PGET('TOOLBAR'):
             self.toolbar = ed_toolbar.EdToolBar(self, wx.ID_ANY)
             self.SetToolBar(self.toolbar)
 
@@ -215,7 +216,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # Edit Menu Events
         self.Bind(wx.EVT_MENU, self.DispatchToControl)
         self.Bind(wx.EVT_MENU, self.nb.FindService.OnShowFindDlg, id=ID_FIND)
-        self.Bind(wx.EVT_MENU, self.nb.FindService.OnShowFindDlg, id=ID_FIND_REPLACE)
+        self.Bind(wx.EVT_MENU, self.nb.FindService.OnShowFindDlg, 
+                  id=ID_FIND_REPLACE)
         self.Bind(wx.EVT_MENU, self.OnQuickFind, id=ID_QUICK_FIND)
         self.Bind(wx.EVT_MENU, self.OnPreferences, id=ID_PREF)
 
@@ -253,30 +255,27 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         #---- Final Setup Calls ----#
         self._exiting = False
-        self.LoadFileHistory(int(PROFILE['FHIST_LVL']))
+        self.LoadFileHistory(_PGET('FHIST_LVL', fmt='int'))
         self.UpdateToolBar()
 
         #---- Set Position and Size ----#
-        if PROFILE.has_key('ALPHA'):
-            self.SetTransparent(PROFILE['ALPHA'])
-        if PROFILE['SET_WPOS'] and PROFILE.has_key('WPOS') and \
-          isinstance(PROFILE['WPOS'], tuple) and len(PROFILE['WPOS']) == 2:
-            self.SetPosition(PROFILE['WPOS'])
+        self.SetTransparent(_PGET('ALPHA', default=255))
+        if _PGET('SET_WPOS') and _PGET('WPOS', "size_tuple", False):
+            self.SetPosition(_PGET('WPOS'))
         else:
             self.CenterOnParent()
 
         # Call add on plugins
-        try:
-            plgmgr = wx.GetApp().GetPluginManager()
-            addons = MainWindowAddOn(plgmgr)
-            addons.Init(self)
-            self._generator = generator.Generator(plgmgr)
-            self._generator.InstallMenu(self.toolsmenu)
-        finally:
-            pass
+        self.LOG("[main][info] Loading MainWindow Plugins ")
+        plgmgr = wx.GetApp().GetPluginManager()
+        addons = MainWindowAddOn(plgmgr)
+        addons.Init(self)
+        self.LOG("[main][info] Loading Generator plugins")
+        self._generator = generator.Generator(plgmgr)
+        self._generator.InstallMenu(self.toolsmenu)
 
         # Set Perspective
-        self.SetPerspective(PROFILE['DEFAULT_VIEW'])
+        self.SetPerspective(_PGET('DEFAULT_VIEW'))
         self._mgr.Update()
         self.Show(True)
 
@@ -312,7 +311,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                     dirname = util.GetPathName(path)
                     filename = util.GetFileName(path)
                     self.nb.OpenPage(dirname, filename)		   
-                    self.SetTitle("%s - file://%s/%s" % (filename, dirname, filename))
+                    self.SetTitle("%s - file://%s/%s" % \
+                                  (filename, dirname, filename))
                     self.nb.GoCurrentPage()
             else:
                 pass
@@ -343,12 +343,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         file_key = "FILE"
-        for i in range(size - 1):
+        keys = range(size - 1)
+        keys.reverse()
+        for i in keys:
             key = file_key + str(i)
-            try:
-                self.filehistory.AddFileToHistory(PROFILE[key])
-            except KeyError: 
-                self.LOG("[main] [exception] Invalid Key on LoadFileHistory")
+            path = _PGET(key, "str")
+            if isinstance(path, basestring) and path != wx.EmptyString:
+                self.filehistory.AddFileToHistory(path)
+            else:
+                pass
 
     def OnNew(self, evt):
         """Star a New File
@@ -427,8 +430,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                      self.nb.GetCurrentCtrl())]
         elif e_id == ID_SAVEALL:
             for page in range(self.nb.GetPageCount()):
-                if issubclass(self.nb.GetPage(page).__class__, wx.stc.StyledTextCtrl):
-                    ctrls.append((self.nb.GetPageText(page), self.nb.GetPage(page)))
+                if issubclass(self.nb.GetPage(page).__class__, 
+                                           wx.stc.StyledTextCtrl):
+                    ctrls.append((self.nb.GetPageText(page), 
+                                  self.nb.GetPage(page)))
         else:
             evt.Skip()
             return
@@ -462,7 +467,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         dlg = wx.FileDialog(self, _("Choose a Save Location"), u'', 
                             title.lstrip(u"*"), self.MenuFileTypes(), 
-                            wx.SAVE|wx.OVERWRITE_PROMPT)
+                            wx.SAVE | wx.OVERWRITE_PROMPT)
         result = dlg.ShowModal()
         if result == wx.ID_OK:
             path = dlg.GetPath()
@@ -498,15 +503,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         if evt.GetId() == ID_SAVE_PROFILE:
             dlg = wx.FileDialog(self, _("Where to Save Profile?"), \
-                               CONFIG['PROFILE_DIR'], "default.pp", \
-                               _("Profile") + " (*.pp)|*.pp", 
+                               CONFIG['PROFILE_DIR'], "default.ppb", \
+                               _("Profile") + " (*.ppb)|*.ppb", 
                                 wx.SAVE | wx.OVERWRITE_PROMPT)
 
             result = dlg.ShowModal()
             if result == wx.ID_OK: 
                 profile = dlg.GetFilename()
                 path = dlg.GetPath()
-                profiler.WriteProfile(path)
+                profiler.Profile().Write(path)
                 self.PushStatusText(_("Profile Saved as: %s") % profile, SB_INFO)
                 dlg.Destroy()
             else:
@@ -523,14 +528,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         if evt.GetId() == ID_LOAD_PROFILE:
             dlg = wx.FileDialog(self, _("Load a Custom Profile"), 
-                                CONFIG['PROFILE_DIR'], "default.pp", 
-                                _("Profile") + " (*.pp)|*.pp", wx.OPEN)
+                                CONFIG['PROFILE_DIR'], "default.ppb", 
+                                _("Profile") + " (*.ppb)|*.ppb", wx.OPEN)
 
             result = dlg.ShowModal()
             if result == wx.ID_OK: 
                 profile = dlg.GetFilename()
                 path = dlg.GetPath()
-                profiler.ReadProfile(path)
+                profiler.Profile().Load()(path)
                 self.PushStatusText(_("Loaded Profile: %s") % profile, SB_INFO)
                 dlg.Destroy()
             else:
@@ -550,7 +555,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         e_id = evt.GetId()
-        pmode = PROFILE['PRINT_MODE'].replace(u'/', u'_').lower()
+        pmode = _PGET('PRINT_MODE', "str").replace(u'/', u'_').lower()
         self.printer.SetColourMode(pmode)
         if e_id == ID_PRINT:
             self.printer.Print()
@@ -612,15 +617,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # XXX workaround for possible bug in wxPython 2.8
         if wx.Platform == '__WXMAC__' and self.GetToolBar():
             self.toolbar.Destroy()
-        PROFILE['WSIZE'] = self.GetSize()
-        PROFILE['WPOS'] = self.GetPosition()
+        _PSET('WSIZE', self.GetSizeTuple())
+        _PSET('WPOS', self.GetPositionTuple())
         self.LOG("[main_evt] [exit] Closing editor at pos=%s size=%s" % \
-                 (str(PROFILE['WPOS']), str(PROFILE['WSIZE'])))
+                 (_PGET('WPOS', 'str'), _PGET('WSIZE', 'str')))
         
         # Update profile
         profiler.UpdateProfileLoader()
         profiler.AddFileHistoryToProfile(self.filehistory)
-        profiler.WriteProfile(PROFILE['MYPROFILE'])
+        profiler.Profile().Write(_PGET('MYPROFILE'))
 
         # Cleanup file history
         try:
@@ -683,14 +688,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         if evt.GetId() == ID_VIEW_TOOL:
-            if PROFILE['TOOLBAR'] and self.toolbar != None:
+            if _PGET('TOOLBAR', 'bool', False) and self.toolbar != None:
                 self.toolbar.Destroy()
                 del self.toolbar
-                PROFILE['TOOLBAR'] = False
+                _PSET('TOOLBAR', False)
             else:
                 self.toolbar = ed_toolbar.EdToolBar(self, wx.ID_ANY)
                 self.SetToolBar(self.toolbar)
-                PROFILE['TOOLBAR'] = True
+                _PSET('TOOLBAR', True)
                 self.UpdateToolBar()
         else:
             evt.Skip()
@@ -699,7 +704,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
     #---- Format Menu Functions ----#
     def OnFont(self, evt):
-        """Open Font Settings Dialog
+        """Open Font Settings Dialog for changing fonts on a per document
+        basis.
         @status: This currently does not allow for font settings to stick
                  from one session to the next.
         @param evt: Event fired that called this handler
@@ -707,17 +713,18 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         if evt.GetId() == ID_FONT:
-            dlg = wx.FontDialog(self, wx.FontData())
+            ctrl = self.nb.GetCurrentCtrl()
+            fdata = wx.FontData()
+            fdata.SetInitialFont(ctrl.GetDefaultFont())
+            dlg = wx.FontDialog(self, fdata)
             result = dlg.ShowModal()
             data = dlg.GetFontData()
-
+            dlg.Destroy()
             if result == wx.ID_OK:
                 font = data.GetChosenFont()
-                ctrl = self.nb.GetCurrentCtrl()
-                ctrl.SetGlobalFont(self.nb.control.FONT_TAG_MONO, \
-                                   font.GetFaceName())
+                ctrl.SetGlobalFont(self.nb.control.FONT_PRIMARY, \
+                                   font.GetFaceName(), font.GetPointSize())
                 ctrl.UpdateAllStyles()
-            dlg.Destroy()
         else:
             evt.Skip()
 
@@ -843,6 +850,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type evt: wxMenuEvent
 
         """
+        if not self.IsActive():
+            evt.Skip()
+            return
+        
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
         menu_ids = syntax.SyntaxIds()
@@ -971,6 +982,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             sel1, sel2 = ctrl.GetSelection()
             menu.Enable(ID_COPY, sel1 != sel2)
             menu.Enable(ID_CUT, sel1 != sel2)
+            menu.Enable(ID_FIND, True)
+            menu.Enable(ID_FIND_REPLACE, True)
         elif menu == self.settingsmenu:
             self.LOG("[menu_evt] Updating Settings Menu")
             menu.Check(ID_AUTOCOMP, ctrl.GetAutoComplete())
@@ -1038,7 +1051,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         dlg.Destroy()
 
         if result == wx.ID_YES:
-            self.OnSave(ID_SAVE)
+            self.OnSave(wx.MenuEvent(wx.wxEVT_COMMAND_MENU_SELECTED, ID_SAVE))
 
         return result
 
@@ -1080,5 +1093,9 @@ class MainWindowAddOn(plugin.Plugin):
         @param window: window that observers become children of
 
         """
+        log = wx.GetApp().GetLog()
         for ob in self.observers:
-            ob.PlugIt(window)
+            try:
+                ob.PlugIt(window)
+            except Exception, msg:
+                log("[main_addon][err] %s" % str(msg))
