@@ -42,8 +42,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 269 2007-07-08 13:39:29Z CodyPrecord $"
-__revision__ = "$Revision: 269 $"
+__svnid__ = "$Id: ed_pages.py 310 2007-07-22 02:29:01Z CodyPrecord $"
+__revision__ = "$Revision: 310 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -52,25 +52,22 @@ import glob
 import re
 import wx
 import ed_glob
+from profiler import Profile_Get
 import ed_event
 import ed_stc
 import syntax.synglob as synglob
 import ed_search
 import util
 import doctools
-import wx.lib.flatnotebook as FNB
+# import wx.lib.flatnotebook as FNB
+# Use local copy until newer release of wxpython
+from extern import flatnotebook as FNB
 
 #---- Class Globals ----#
 # HACK till proper artprovider can be written
 IMG = {}
 
 _ = wx.GetTranslation
-
-# Compatibility for wxPython versions before 2.8.4
-if hasattr(FNB, 'FNB_FF2'):
-    TAB_STYLE = FNB.FNB_FF2
-else:
-    TAB_STYLE = FNB.FNB_FANCY_TABS
 #--------------------------------------------------------------------------#
 class EdPages(FNB.FlatNotebook):
     """Editras Notebook
@@ -84,10 +81,11 @@ class EdPages(FNB.FlatNotebook):
 
         """
         FNB.FlatNotebook.__init__(self, parent, id_num, 
-                                  style = TAB_STYLE |
-                                          FNB.FNB_X_ON_TAB | 
-                                          FNB.FNB_SMART_TABS |
-                                          FNB.FNB_BACKGROUND_GRADIENT
+                                  style=FNB.FNB_FF2 |
+                                        FNB.FNB_X_ON_TAB | 
+                                        FNB.FNB_SMART_TABS |
+                                        FNB.FNB_BACKGROUND_GRADIENT |
+                                        FNB.FNB_DROPDOWN_TABS_LIST
                             )
 
         # Notebook attributes
@@ -102,6 +100,8 @@ class EdPages(FNB.FlatNotebook):
 
         # Set Additional Style Parameters
         self.SetNonActiveTabTextColour(wx.ColourRGB(long("666666", 16)))
+        ed_icon = ed_glob.CONFIG['SYSPIX_DIR'] + u"editra.png"
+        self.SetNavigatorIcon(wx.Bitmap(ed_icon, wx.BITMAP_TYPE_PNG))
 
         # Setup the ImageList and the default image
         imgl = wx.ImageList(16, 16)
@@ -246,7 +246,7 @@ class EdPages(FNB.FlatNotebook):
         self.control.CheckEOL()
         self.control.EmptyUndoBuffer()
 
-        if ed_glob.PROFILE['SAVE_POS']:
+        if Profile_Get('SAVE_POS'):
             self.control.GotoPos(self.DocMgr.GetPos(self.control.GetFileName()))
 
         # Set tab image
@@ -370,7 +370,7 @@ class EdPages(FNB.FlatNotebook):
         @type evt: wx.IdleEvent
 
         """
-        if ed_glob.PROFILE['CHECKMOD'] and \
+        if Profile_Get('CHECKMOD') and \
            wx.GetApp().IsActive() and self.GetPageCount():
             cfile = os.path.join(self.control.dirname, self.control.filename)
             lmod = util.GetFileModTime(cfile)
