@@ -35,13 +35,14 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 269 2007-07-08 13:39:29Z CodyPrecord $"
-__revision__ = "$Revision: 269 $"
+__svnid__ = "$Id: ed_search.py 317 2007-07-22 06:20:46Z CodyPrecord $"
+__revision__ = "$Revision: 317 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import wx
 import ed_glob
+from profiler import Profile_Get
 import dev_tool
 
 _ = wx.GetTranslation
@@ -199,8 +200,7 @@ class TextFinder(object):
         evt.Skip()
 
     def OnShowFindDlg(self, evt):
-        """Catches the Find events and organizes the data
-        before pushing it to the DoFind Function.
+        """Catches the Find events and shows the appropriate find dialog
         @param evt: event that called this handler
         @postcondition: find dialog is shown
 
@@ -218,10 +218,10 @@ class TextFinder(object):
             self._find_dlg = wx.FindReplaceDialog(self._parent, self._data, \
                                                   _("Find"), wx.FR_NOUPDOWN)
         else:
+            evt.Skip()
             return
-        if wx.Platform == '__WXMAC__' and ed_glob.PROFILE.has_key('METAL'):
-            if ed_glob.PROFILE['METAL']:
-                self._find_dlg.SetExtraStyle(wx.DIALOG_EX_METAL)
+        if wx.Platform == '__WXMAC__' and Profile_Get('METAL', 'bool', False):
+            self._find_dlg.SetExtraStyle(wx.DIALOG_EX_METAL)
         self._find_dlg.CenterOnParent()
         self._find_dlg.Show()
 
