@@ -35,18 +35,20 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 267 2007-07-07 10:38:04Z CodyPrecord $"
-__revision__ = "$Revision: 267 $"
+__cvsid__ = "$Id: plugdlg.py 315 2007-07-22 04:29:35Z CodyPrecord $"
+__revision__ = "$Revision: 315 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import sys
 import os
+import re
 import urllib
 import wx
 import wx.lib.delayedresult as delayedresult
 import wx.lib.mixins.listctrl as listmix
 import ed_glob
+from profiler import Profile_Get
 import ed_event
 import plugin
 import util
@@ -78,6 +80,9 @@ class PluginDialog(wx.Frame):
         wx.Frame.__init__(self, parent, fid, title, pos, size, style)
         util.SetWindowIcon(self)
 
+        if wx.Platform == '__WXMAC__' and Profile_Get('METAL', 'bool', False):
+            self.SetExtraStyle(wx.FRAME_EX_METAL)
+
         # Attributes
         self._sizer = wx.BoxSizer(wx.VERTICAL)
         self.CreateStatusBar(2)
@@ -231,7 +236,7 @@ class ConfigPanel(wx.Panel):
         if self.HasItem(name):
             item_id = self._list.FindItem(0, name)
             ver = self._list.GetItem(item_id, self._list.VERSION_COL)
-            identifer = name + ver.GetText()
+            identifer = (name, ver.GetText())
         return identifer
 
     def HasItem(self, name):
@@ -313,6 +318,10 @@ class ConfigPanel(wx.Panel):
 class DownloadPanel(wx.Panel):
     """Creates a panel with controls for downloading plugins."""
     ID_DOWNLOAD = wx.NewId()
+    EGG_PATTERN = re.compile(r"(?P<name>[^-]+)"
+    r"( -(?P<ver>[^-]+) (-py(?P<pyver>[^-]+) (-(?P<plat>.+))? )? )?",
+    re.VERBOSE | re.IGNORECASE
+    ).match
 
     def __init__(self, parent, pid=wx.ID_ANY, style=wx.NO_BORDER):
         """Initializes the panel"""
@@ -445,9 +454,10 @@ class DownloadPanel(wx.Panel):
         config_pg = self.GetParent().GetPage(CONFIG_PG)
         to_clean = list()
         for pin in p_list:
-            pin_id = p_list[pin].GetName() + p_list[pin].GetVersion()
+            ver = p_list[pin].GetVersion()
+            pin_id = p_list[pin].GetName() + ver
             cfg_id = config_pg.GetItemIdentifier(pin.lower())
-            if cfg_id and cfg_id.lower() == pin_id.lower():
+            if cfg_id is not None and cfg_id[1] >= ver:
                 to_clean.append(pin)
         for item in to_clean:
             del p_list[item]
@@ -472,10 +482,11 @@ class DownloadPanel(wx.Panel):
 
         """
         e_id = evt.GetId()
+        print self._dl_list
         if e_id == self.ID_DOWNLOAD:
             urls = list()
             for item in self._dl_list:
-                if self._dl_list[item]:
+                if self._dl_list[item] and item in self._p_list:
                     urls.append(BASE_URL + self._p_list[item].GetUrl())
             self._eggcount = len(urls)
             for egg in range(len(urls)):
@@ -530,6 +541,23 @@ class DownloadPanel(wx.Panel):
             self._list.SendSizeEvent()
         return self._list.GetItemCount()
 
+    def RemoveDownloadedItem(self, item):
+        """Remove an item from the download cache
+        @param item: Name of item to remove
+
+        """
+        # Removed downloaded data
+        if self._eggbasket.has_key(item):
+            del self._eggbasket[item]
+
+        # Remove download entry data
+        match = self.EGG_PATTERN(item)
+        if match:
+            plugin_name = match.group('name').lower()
+            print plugin_name
+            if self._dl_list.has_key(plugin_name):
+                del self._dl_list[plugin_name]
+
 class InstallPanel(wx.Panel):
     """Creates a panel for installing plugins."""
     ID_INSTALL = wx.NewId()
@@ -551,7 +579,8 @@ class InstallPanel(wx.Panel):
                              "and hit Delete or Backspace."))
         self._install = wx.ListBox(self, wx.ID_ANY, style=wx.LB_SORT)
         self._install.SetToolTip(toolt)
-        self._install.SetDropTarget(util.DropTargetFT(self))
+        self._install.SetDropTarget(util.DropTargetFT(self._install, 
+                                                      None, self.OnDrop))
         self._instb = wx.Button(self, self.ID_INSTALL, _("Install"))
         self._instb.Disable()
         self._usercb = wx.CheckBox(self, self.ID_USER, _("User Directory"))
@@ -564,7 +593,7 @@ class InstallPanel(wx.Panel):
         self._syscb.SetToolTip(toolt)
         if not util.CanWrite(ed_glob.CONFIG['SYS_PLUGIN_DIR']):
             self._syscb.Disable()
-        
+
         # Layout Panel
         self._sizer.Add(lbl, 0, wx.ALIGN_CENTER)
         self._sizer.Add(self._install, 1, wx.EXPAND)
@@ -604,7 +633,7 @@ class InstallPanel(wx.Panel):
                     reader = file(item, "rb")
                     egg = reader.read()
                     reader.close()
-                except IOError:
+                except (IOError, SystemError, OSError):
                     continue
             else:
                 dl_pg = self.GetParent().GetPage(DOWNLOAD_PG)
@@ -621,8 +650,10 @@ class InstallPanel(wx.Panel):
             else:
                 # If successfully installed remove from list
                 ind = self._install.FindString(item)
+                dl_pg = self.GetParent().GetPage(DOWNLOAD_PG)
                 if ind != wx.NOT_FOUND:
                     self._install.Delete(ind)
+                    dl_pg.RemoveDownloadedItem(item)
 
         if not len(self._install.GetItems()):
             # All plugins installed correctly
