@@ -31,8 +31,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 288 2007-07-12 11:48:55Z CodyPrecord $"
-__revision__ = "$Revision: 288 $"
+__svnid__ = "$Id: prefdlg.py 322 2007-07-25 09:37:15Z CodyPrecord $"
+__revision__ = "$Revision: 322 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -40,6 +40,8 @@ import wx
 import wx.lib.mixins.listctrl as listmix
 import sys
 import ed_glob
+import profiler
+from profiler import Profile_Get, Profile_Set
 import ed_i18n
 import ed_event
 import updater
@@ -89,10 +91,9 @@ class PreferencesDialog(wx.Frame):
 
         # Extra Styles
         self.SetExtraStyle(wx.FRAME_EX_CONTEXTHELP)
-        self.SetTransparent(ed_glob.PROFILE.get('ALPHA', 255))
-        if wx.Platform == '__WXMAC__' and ed_glob.PROFILE.has_key('METAL'):
-            if ed_glob.PROFILE['METAL']:
-                self.SetExtraStyle(wx.DIALOG_EX_METAL)
+        self.SetTransparent(Profile_Get('ALPHA', 'int', 255))
+        if wx.Platform == '__WXMAC__' and Profile_Get('METAL', 'bool', False):
+            self.SetExtraStyle(wx.DIALOG_EX_METAL)
 
         # Attributes
         self._tbook = PrefTools(self)
@@ -135,6 +136,8 @@ class PrefTools(wx.Toolbook):
         """Initializes the main book control of the preferences dialog
         @summary: creates the top level notebook control for the prefdlg
                   a toolbar is used for changing pages.
+        @todo: there is some nasty dithering/icon rescaling happening on
+               osx. need to se why this is.
 
         """
         wx.Toolbook.__init__(self, parent, tbid, style=style)
@@ -295,42 +298,45 @@ class GeneralPanel(PrefPanelBase):
         mode_lbl = wx.StaticText(self, label=_("Editor Mode") + u": ")
         mode_ch = ExChoice(self, ed_glob.ID_PREF_MODE,
                            choices=['CODE', 'DEBUG', 'GUI_DEBUG'],
-                           default=ed_glob.PROFILE['MODE'])
+                           default=Profile_Get('MODE'))
         msizer = wx.BoxSizer(wx.HORIZONTAL)
         msizer.AddMany([(mode_lbl, 0), ((5, 5), 0), (mode_ch, 0)])
         pmode_lbl = wx.StaticText(self, label=_("Printer Mode") + u": ")
         pmode_ch = ExChoice(self, ed_glob.ID_PRINT_MODE,
                             choices=['Black/White', 'Colour/White', 
                                      'Colour/Default', 'Inverse', 'Normal'],
-                            default=ed_glob.PROFILE['PRINT_MODE'])
+                            default=Profile_Get('PRINT_MODE'))
         psizer = wx.BoxSizer(wx.HORIZONTAL)
         psizer.AddMany([(pmode_lbl, 0), ((5, 5), 0), (pmode_ch, 0)])
         splash_cb = wx.CheckBox(self, ed_glob.ID_APP_SPLASH, 
                                 _("Show Splash Screen"))
-        splash_cb.SetValue(ed_glob.PROFILE['APPSPLASH'])
+        splash_cb.SetValue(Profile_Get('APPSPLASH'))
+        reporter_cb = wx.CheckBox(self, ed_glob.ID_REPORTER, 
+                                  _("Disable Error Reporter"))
+        reporter_cb.SetValue(not Profile_Get('REPORTER'))
 
         # File settings
         file_lbl = wx.StaticText(self, label=_("File Settings") + u": ")
         fh_lbl = wx.StaticText(self, label=_("File History Length") + u": ")
         fh_ch = ExChoice(self, ed_glob.ID_PREF_FHIST,
                          choices=['1','2','3','4','5','6','7','8','9'],
-                         default=str(ed_glob.PROFILE['FHIST_LVL']))
+                         default=Profile_Get('FHIST_LVL', 'str'))
         fhsizer = wx.BoxSizer(wx.HORIZONTAL)
         fhsizer.AddMany([(fh_lbl, 0), ((5, 5), 0), (fh_ch, 0)])
         pos_cb = wx.CheckBox(self, ed_glob.ID_PREF_SPOS, 
                              _("Remember File Position"))
-        pos_cb.SetValue(ed_glob.PROFILE['SAVE_POS'])
+        pos_cb.SetValue(Profile_Get('SAVE_POS'))
         chkmod_cb = wx.CheckBox(self, ed_glob.ID_PREF_CHKMOD, 
                                 _("Check if on disk file has been "
                                   "modified by others"))
-        chkmod_cb.SetValue(ed_glob.PROFILE['CHECKMOD'])
+        chkmod_cb.SetValue(Profile_Get('CHECKMOD'))
 
         # Locale
         locale = wx.StaticText(self, label=_("Locale Settings") + u": ")
         lsizer = wx.BoxSizer(wx.HORIZONTAL)
         lang_lbl = wx.StaticText(self, label=_("Language") + u": ")
         lang_c = ed_i18n.LangListCombo(self, ed_glob.ID_PREF_LANG, 
-                                       ed_glob.PROFILE['LANG'])
+                                       Profile_Get('LANG'))
         lsizer.AddMany([(lang_lbl, 0), ((5, 5), 0), (lang_c, 0)])
 
         # Layout items
@@ -339,12 +345,13 @@ class GeneralPanel(PrefPanelBase):
                        (start_lbl, (1, 1)),
                        (msizer, (1, 2), (1, 2)),
                        (psizer, (2, 2), (1, 2)),
-                       (splash_cb, (3, 2), (1, 2))])
-        sizer.AddMany([(file_lbl, (5, 1)),
-                       (fhsizer, (5, 2), (1, 2)), (pos_cb, (6, 2), (1, 3)),
-                       (chkmod_cb, (7, 2), (1, 2))])
-        sizer.AddMany([(locale, (9, 1)),
-                       (lsizer, (9, 2), (1, 3))])
+                       (splash_cb, (3, 2), (1, 2)),
+                       (reporter_cb, (4, 2), (1, 2))])
+        sizer.AddMany([(file_lbl, (6, 1)),
+                       (fhsizer, (6, 2), (1, 2)), (pos_cb, (7, 2), (1, 3)),
+                       (chkmod_cb, (8, 2), (1, 2))])
+        sizer.AddMany([(locale, (10, 1)),
+                       (lsizer, (10, 2), (1, 3))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -355,9 +362,13 @@ class GeneralPanel(PrefPanelBase):
         self.LOG("[prefdlg][gen][evt] Check box clicked")
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
-        if e_id is [ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
+        if e_id in [ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
                     ed_glob.ID_PREF_CHKMOD]:
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
+        elif e_id == ed_glob.ID_REPORTER:
+            Profile_Set(ed_glob.ID_2_PROF[e_id], not e_obj.GetValue())
+        else:
+            pass
         evt.Skip()
 
     def OnChoice(self, evt):
@@ -371,7 +382,9 @@ class GeneralPanel(PrefPanelBase):
         e_obj = evt.GetEventObject()
         if e_id in [ed_glob.ID_PREF_MODE, ed_glob.ID_PRINT_MODE,
                     ed_glob.ID_PREF_FHIST, ed_glob.ID_PREF_LANG]:
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
+            if e_id == ed_glob.ID_PREF_MODE:
+                ed_glob.DEBUG = ('DEBUG' in e_obj.GetValue())
         else:
             evt.Skip()
 
@@ -413,6 +426,9 @@ class DocGenPanel(wx.Panel):
               how a document is managed.
 
     """
+    ID_FONT_PICKER = wx.NewId()
+    ID_FONT_PICKER2 = wx.NewId()
+
     def __init__(self, parent):
         """Create the panel
         @param parent: Parent window of this panel
@@ -426,6 +442,7 @@ class DocGenPanel(wx.Panel):
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnUpdateEditor)
         self.Bind(wx.EVT_CHOICE, self.OnUpdateEditor)
+        self.Bind(ed_event.EVT_NOTIFY, self.OnFontChange)
 
     def _DoLayout(self):
         """Layout the controls
@@ -436,28 +453,42 @@ class DocGenPanel(wx.Panel):
         tabw_lbl = wx.StaticText(self, label=_("Tab Width") + u": ")
         tw_ch = ExChoice(self, ed_glob.ID_PREF_TABW,
                           choices=['2','3','4','5','6','7','8','9','10'],
-                          default=str(ed_glob.PROFILE['TABWIDTH']))
+                          default=Profile_Get('TABWIDTH', 'str'))
         ut_cb = wx.CheckBox(self, ed_glob.ID_PREF_TABS, 
                             _("Use Tabs Instead of Spaces"))
-        ut_cb.SetValue(ed_glob.PROFILE['USETABS'])
+        ut_cb.SetValue(Profile_Get('USETABS', 'bool', False))
         eol_lbl = wx.StaticText(self, label=_("Default EOL Mode") + u": ")
         eol_ch = ExChoice(self, ed_glob.ID_EOL_MODE,
-                          choices = [_("Macintosh (\\r)"), _("Unix (\\n)"), 
+                          choices=[_("Macintosh (\\r)"), _("Unix (\\n)"), 
                                    _("Windows (\\r\\n)")],
-                          default = ed_glob.PROFILE['EOL'])
+                          default=Profile_Get('EOL'))
 
         # View Options
         view_lbl = wx.StaticText(self, label=_("View Options") + u": ")
         aa_cb = wx.CheckBox(self, ed_glob.ID_PREF_AALIAS, _("AntiAliasing"))
-        aa_cb.SetValue(ed_glob.PROFILE['AALIASING'])
+        aa_cb.SetValue(Profile_Get('AALIASING'))
         seol_cb = wx.CheckBox(self, ed_glob.ID_SHOW_EOL, _("Show EOL Markers"))
-        seol_cb.SetValue(ed_glob.PROFILE['SHOW_EOL'])
+        seol_cb.SetValue(Profile_Get('SHOW_EOL'))
         sln_cb = wx.CheckBox(self, ed_glob.ID_SHOW_LN, _("Show Line Numbers"))
-        sln_cb.SetValue(ed_glob.PROFILE['SHOW_LN'])
+        sln_cb.SetValue(Profile_Get('SHOW_LN'))
         sws_cb = wx.CheckBox(self, ed_glob.ID_SHOW_WS, _("Show Whitespace"))
-        sws_cb.SetValue(ed_glob.PROFILE['SHOW_WS'])
+        sws_cb.SetValue(Profile_Get('SHOW_WS'))
         ww_cb = wx.CheckBox(self, ed_glob.ID_WORD_WRAP, _("Word Wrap"))
-        ww_cb.SetValue(ed_glob.PROFILE['WRAP'])
+        ww_cb.SetValue(Profile_Get('WRAP'))
+
+        # Font Options
+        main = wx.GetApp().GetMainWindow()
+        font_lbl = wx.StaticText(self, label=_("Primary Font") + u": ")
+        fnt = main.nb.GetCurrentCtrl().GetStyleFont()
+        fpicker = PyFontPicker(self, self.ID_FONT_PICKER, fnt)
+        tt = wx.ToolTip(_("Sets the main/default font of the document"))
+        fpicker.SetToolTip(tt)
+        font_lbl2 = wx.StaticText(self, label=_("Secondary Font") + u": ")
+        fnt = main.nb.GetCurrentCtrl().GetStyleFont(False)
+        fpicker2 = PyFontPicker(self, self.ID_FONT_PICKER2, fnt)
+        tt = wx.ToolTip(_("Sets a secondary font used for special regions "
+                          "when syntax highlighting is in use"))
+        fpicker2.SetToolTip(tt)
 
         # Layout
         sizer = wx.GridBagSizer(5, 5)
@@ -468,10 +499,31 @@ class DocGenPanel(wx.Panel):
                        (eol_lbl, (3, 2)), (eol_ch, (3, 3), wx.GBSpan(1, 2)),
                        ((5, 5), (5, 0)), (view_lbl, (5, 1)),
                        (aa_cb, (5, 2)), (seol_cb, (6, 2)), (sln_cb, (7, 2)),
-                       (sws_cb, (8, 2)), (ww_cb, (9, 2))
+                       (sws_cb, (8, 2)), (ww_cb, (9, 2)),
+                       (font_lbl, (11, 1)), 
+                       (fpicker, (11, 2), (1, 3), wx.EXPAND), 
+                       (font_lbl2, (12, 1)),
+                       (fpicker2, (12, 2), (1, 3), wx.EXPAND)
                        ])
         self.SetSizer(sizer)
 
+    def OnFontChange(self, evt):
+        """Handles L{ed_event.EVT_NOTIFY} from the font controls"""
+        e_id = evt.GetId()
+        if e_id in [self.ID_FONT_PICKER, self.ID_FONT_PICKER2]:
+            font = evt.GetValue()
+            if e_id == self.ID_FONT_PICKER:
+                Profile_Set('FONT1', font, 'font')
+            else:
+                Profile_Set('FONT2', font, 'font')
+            main = wx.GetApp().GetMainWindow()
+            if main:
+                for stc in main.nb.GetTextControls():
+                    stc.SetStyleFont(font, e_id == self.ID_FONT_PICKER)
+                    stc.UpdateAllStyles()
+        else:
+            evt.Skip()
+
     def OnUpdateEditor(self, evt):
         """Update any open text controls to reflect the changes made in this
         panel from the checkboxes and choice controls.
@@ -483,8 +535,9 @@ class DocGenPanel(wx.Panel):
         if e_id in [ed_glob.ID_PREF_TABS, ed_glob.ID_PREF_TABW,
                     ed_glob.ID_EOL_MODE, ed_glob.ID_PREF_AALIAS,
                     ed_glob.ID_SHOW_EOL, ed_glob.ID_SHOW_LN,
-                    ed_glob.ID_SHOW_WS, ed_glob.ID_WORD_WRAP]:
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = e_obj.GetValue()
+                    ed_glob.ID_SHOW_WS, ed_glob.ID_WORD_WRAP,
+                     ed_glob.ID_PREF_AALIAS]:
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             mainw = wx.GetApp().GetMainWindow()
             if mainw is not None:
                 mainw.nb.UpdateTextControls()
@@ -510,6 +563,7 @@ class DocCodePanel(wx.Panel):
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         self.Bind(wx.EVT_CHOICE, self.OnCheck)
+        self.Bind(wx.EVT_SLIDER, self.OnSlide)
 
     def _DoLayout(self):
         """Layout the page
@@ -520,24 +574,25 @@ class DocCodePanel(wx.Panel):
         vis_lbl = wx.StaticText(self, label=_("Visual Helpers") + u": ")
         br_cb = wx.CheckBox(self, ed_glob.ID_BRACKETHL, 
                             _("Bracket Highlighting"))
-        br_cb.SetValue(ed_glob.PROFILE['BRACKETHL'])
+        br_cb.SetValue(Profile_Get('BRACKETHL'))
         fold_cb = wx.CheckBox(self, ed_glob.ID_FOLDING, _("Code Folding"))
-        fold_cb.SetValue(ed_glob.PROFILE['CODE_FOLD'])
+        fold_cb.SetValue(Profile_Get('CODE_FOLD'))
         edge_cb = wx.CheckBox(self, ed_glob.ID_SHOW_EDGE, _("Edge Guide"))
-        edge_cb.SetValue(ed_glob.PROFILE['SHOW_EDGE'])
+        edge_cb.SetValue(Profile_Get('SHOW_EDGE'))
         
-        edge_ch = ExChoice(self, ed_glob.ID_PREF_EDGE,
-                           choices=range(40, 101),
-                           default=str(ed_glob.PROFILE['EDGE']))
+        edge_sl = wx.Slider(self, ed_glob.ID_PREF_EDGE, Profile_Get('EDGE'),
+                            0, 100, size=(-1, 15), style=wx.SL_HORIZONTAL | \
+                            wx.SL_AUTOTICKS | wx.SL_LABELS)
+        edge_sl.SetTickFreq(5, 1)
         ind_cb = wx.CheckBox(self, ed_glob.ID_INDENT_GUIDES, 
                              _("Indentation Guides"))
-        ind_cb.SetValue(ed_glob.PROFILE['GUIDES'])
+        ind_cb.SetValue(Profile_Get('GUIDES'))
 
         # Input Helpers
         comp_cb = wx.CheckBox(self, ed_glob.ID_AUTOCOMP, _("Auto-Completion"))
-        comp_cb.SetValue(ed_glob.PROFILE['AUTO_COMP'])
+        comp_cb.SetValue(Profile_Get('AUTO_COMP'))
         ai_cb = wx.CheckBox(self, ed_glob.ID_AUTOINDENT, _("Auto-Indent"))
-        ai_cb.SetValue(ed_glob.PROFILE['AUTO_INDENT'])
+        ai_cb.SetValue(Profile_Get('AUTO_INDENT'))
 
         # Layout the controls
         sizer = wx.GridBagSizer(5, 5)
@@ -546,7 +601,7 @@ class DocCodePanel(wx.Panel):
         sizer.AddMany([(br_cb, (1, 2)), (fold_cb, (2, 2)),
                        (edge_cb, (3, 2)),
                        (wx.StaticText(self, label=_("Column") + u": "), (3, 3)),
-                       (edge_ch, (3, 4)), (ind_cb, (4, 2))])
+                       (edge_sl, (3, 4), (2, 2), wx.EXPAND), (ind_cb, (4, 2))])
         sizer.Add(wx.StaticText(self, label=_("Input Helpers") + u": "), (6, 1))
         sizer.AddMany([(comp_cb, (6, 2)), (ai_cb, (7, 2))])
         self.SetSizer(sizer)
@@ -564,13 +619,30 @@ class DocCodePanel(wx.Panel):
                     ed_glob.ID_INDENT_GUIDES, ed_glob.ID_FOLDING,
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
                     ed_glob.ID_PREF_EDGE]:
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             mainw = wx.GetApp().GetMainWindow()
             if mainw is not None:
                 mainw.nb.UpdateTextControls()
         else:
             evt.Skip()
 
+    def OnSlide(self, evt):
+        """Catch actions from a slider
+        @param evt: Event that called this handler.
+
+        """
+        e_id = evt.GetId()
+        e_obj = evt.GetEventObject()
+        if e_id == ed_glob.ID_PREF_EDGE:
+            val = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], val)
+            mainw = wx.GetApp().GetMainWindow()
+            if mainw is not None:
+                for stc in mainw.nb.GetTextControls():
+                    stc.SetEdgeColumn(val)
+        else:
+            evt.Skip()
+
 class DocSyntaxPanel(wx.Panel):
     """Document syntax config panel
     @summary: Manages the configuration of the syntax highlighting
@@ -603,11 +675,11 @@ class DocSyntaxPanel(wx.Panel):
         """
         # Syntax Settings
         syn_cb = wx.CheckBox(self, ed_glob.ID_SYNTAX, _("Syntax Highlighting"))
-        syn_cb.SetValue(ed_glob.PROFILE['SYNTAX'])
+        syn_cb.SetValue(Profile_Get('SYNTAX'))
         syntheme = ExChoice(self, ed_glob.ID_PREF_SYNTHEME,
                             choices=util.GetResourceFiles(u'styles', 
                                                           get_all=True),
-                            default=str(ed_glob.PROFILE['SYNTHEME']))
+                            default=Profile_Get('SYNTHEME', 'str'))
         line = wx.StaticLine(self, size=(-1, 2))
         lsizer = wx.BoxSizer(wx.VERTICAL)
         lsizer.Add(line, 0, wx.EXPAND)
@@ -657,7 +729,7 @@ class DocSyntaxPanel(wx.Panel):
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
         if e_id in [ed_glob.ID_SYNTAX, ed_glob.ID_PREF_SYNTHEME]:
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             mainw = wx.GetApp().GetMainWindow()
             if mainw is not None:
                 mainw.nb.UpdateTextControls()
@@ -697,12 +769,12 @@ class AppearancePanel(PrefPanelBase):
                             choices=util.GetResources(u"pixmaps" + \
                                                       util.GetPathChar() + \
                                                       u"theme"), 
-                            default=ed_glob.PROFILE['ICONS'].title())
+                            default=Profile_Get('ICONS', 'str').title())
         tb_isz_lbl = wx.StaticText(self, wx.ID_ANY, \
                                    _("Toolbar Icon Size") + u": ")
         tb_isz_ch = ExChoice(self, ed_glob.ID_PREF_ICONSZ,
                               choices=['16', '24', '32'],
-                              default=str(ed_glob.PROFILE['ICON_SZ'][0]))
+                              default=str(Profile_Get('ICON_SZ', 'size_tuple')[0]))
 
         # Layout Section
         perspect_lbl = wx.StaticText(self, wx.ID_ANY, \
@@ -714,18 +786,18 @@ class AppearancePanel(PrefPanelBase):
             pchoices = list()
         perspect_ch = ExChoice(self, ed_glob.ID_PERSPECTIVES,
                                choices=pchoices,
-                               default=ed_glob.PROFILE['DEFAULT_VIEW'])
+                               default=Profile_Get('DEFAULT_VIEW'))
         ws_cb = wx.CheckBox(self, ed_glob.ID_PREF_WSIZE, \
                             _("Remember Window Size on Exit"))
-        ws_cb.SetValue(ed_glob.PROFILE['SET_WSIZE'])
+        ws_cb.SetValue(Profile_Get('SET_WSIZE'))
         wp_cb = wx.CheckBox(self, ed_glob.ID_PREF_WPOS, \
                             _("Remember Window Position on Exit"))
-        wp_cb.SetValue(ed_glob.PROFILE['SET_WPOS'])
+        wp_cb.SetValue(Profile_Get('SET_WPOS'))
 
         # Misc
         trans_lbl = wx.StaticText(self, wx.ID_ANY, _("Transparency") + u": ")
         trans = wx.Slider(self, ed_glob.ID_TRANSPARENCY, 
-                          ed_glob.PROFILE['ALPHA'], 100, 255, 
+                          Profile_Get('ALPHA'), 100, 255, 
                           style=wx.SL_HORIZONTAL | wx.SL_AUTOTICKS | 
                                 wx.SL_LABELS)
         tsizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -735,7 +807,7 @@ class AppearancePanel(PrefPanelBase):
         if wx.Platform == '__WXMAC__':
             m_cb = wx.CheckBox(self, ed_glob.ID_PREF_METAL, \
                                _("Use Metal Style (OS X Only)"))
-            m_cb.SetValue(ed_glob.PROFILE.get('METAL', False))
+            m_cb.SetValue(Profile_Get('METAL', 'bool', False))
         else:
             m_cb = (0, 0)
 
@@ -766,10 +838,10 @@ class AppearancePanel(PrefPanelBase):
         e_id = evt.GetId()
         val = evt.GetEventObject().GetValue()
         if e_id in [ed_glob.ID_PREF_WPOS, ed_glob.ID_PREF_WSIZE]:
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = val
+            Profile_Set(ed_glob.ID_2_PROF[e_id], val)
         elif e_id == ed_glob.ID_PREF_METAL:
             windows = wx.GetApp().GetOpenWindows()
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = val
+            Profile_Set(ed_glob.ID_2_PROF[e_id], val)
             for window in windows.values():
                 sty = None
                 if isinstance(window[0], wx.Frame):
@@ -802,17 +874,17 @@ class AppearancePanel(PrefPanelBase):
         if e_id in [ed_glob.ID_PREF_ICON, ed_glob.ID_PREF_ICONSZ]:
             if e_id == ed_glob.ID_PREF_ICONSZ:
                 val = (int(val), int(val))
-            ed_glob.PROFILE[ed_glob.ID_2_PROF[e_id]] = val
+            Profile_Set(ed_glob.ID_2_PROF[e_id], val)
             toolbar = wx.GetApp().GetMainWindow().GetToolBar()
             if toolbar is not None and \
-               (toolbar.GetToolTheme() != ed_glob.PROFILE['ICONS'] \
-               or toolbar.GetToolSize() != ed_glob.PROFILE['ICON_SZ']):
+               (toolbar.GetToolTheme() != Profile_Get('ICONS')) \
+               or (toolbar.GetToolSize() != Profile_Get('ICON_SZ')):
                 toolbar.ReInit()
         elif e_id == ed_glob.ID_PERSPECTIVES:
-            ed_glob.PROFILE['DEFAULT_VIEW'] = e_obj.GetValue()
+            Profile_Set('DEFAULT_VIEW', e_obj.GetValue())
             main_win = wx.GetApp().GetMainWindow()
             if main_win is not None:
-                main_win.SetPerspective(ed_glob.PROFILE['DEFAULT_VIEW'])
+                main_win.SetPerspective(Profile_Get('DEFAULT_VIEW'))
         else:
             evt.Skip()
 
@@ -829,7 +901,7 @@ class AppearancePanel(PrefPanelBase):
                 win = window[0]
                 if hasattr(win, 'SetTransparent'):
                     win.SetTransparent(value)
-            ed_glob.PROFILE['ALPHA'] = value
+            Profile_Set('ALPHA', value)
         else:
             evt.Skip()
 
@@ -969,11 +1041,11 @@ class ProfileListCtrl(wx.ListCtrl,
         self.InsertColumn(0, _("Item"))
         self.InsertColumn(1, _("Value"))
 
-        prof = ed_glob.PROFILE.keys()
+        prof = profiler.Profile().keys()
         prof.sort()
 
         for key in prof:
-            val = unicode(ed_glob.PROFILE[key])
+            val = unicode(Profile_Get(key))
             index = self.InsertStringItem(sys.maxint, key)
             self.SetStringItem(index, 0, key)
             self.SetStringItem(index, 1, val)
@@ -1111,3 +1183,101 @@ class ExChoice(wx.Choice):
         if val.isalpha():
             val.lower()
         return val
+
+class PyFontPicker(wx.Panel):
+    """A slightly enhanced L{wx.FontPickerCtrl} that displays the
+    choosen font in the text control using the choosen font
+    as well as the font's size using nicer formatting.
+
+    """
+    def __init__(self, parent, id_=-1, default=wx.NullFont):
+        """Initializes the PyFontPicker
+        @param default: The font to initialize as selected in the control
+
+        """
+        wx.Panel.__init__(self, parent, id_, style=wx.NO_BORDER)
+
+        # Attributes
+        if default == wx.NullFont:
+            self._font = wx.SystemSettings_GetFont(wx.SYS_SYSTEM_FONT)
+        else:
+            self._font = default
+        self._text = wx.TextCtrl(self, style=wx.TE_CENTER | wx.TE_READONLY)
+        self._text.SetFont(default)
+        self._text.SetValue(u"%s - %dpt" % (self._font.GetFaceName(), \
+                                            self._font.GetPointSize()))
+        self._button = wx.Button(self, label=_("Set Font") + u'...')
+        
+        # Layout
+        self._sizer = wx.BoxSizer(wx.HORIZONTAL)
+        self._sizer.Add(self._text, 1, wx.ALIGN_LEFT)
+        self._sizer.Add((5, 5), 0)
+        self._sizer.Add(self._button, 0, wx.ALIGN_RIGHT)
+        self.SetSizer(self._sizer)
+        self.SetAutoLayout(True)
+        
+        # Event Handlers
+        self.Bind(wx.EVT_BUTTON, self.OnButton, self._button)
+        self.Bind(wx.EVT_FONTPICKER_CHANGED, self.OnChange)
+
+    def GetFont(self):
+        """Gets the currently choosen font
+        @return: wx.Font
+
+        """
+        return self._font
+
+    def GetTextCtrl(self):
+        """Gets the widgets text control
+        @return: wx.TextCtrl
+
+        """
+        return self._text
+
+    def OnButton(self, evt):
+        """Opens the FontDialog and processes the result
+        @param evt: Event that called this handler
+
+        """
+        fdata = wx.FontData()
+        fdata.SetInitialFont(self._font)
+        fdlg = wx.FontDialog(self.GetParent(), fdata)
+        fdlg.ShowModal()
+        fdata = fdlg.GetFontData()
+        fdlg.Destroy()
+        wx.PostEvent(self, wx.FontPickerEvent(self, self.GetId(), 
+                                              fdata.GetChosenFont()))
+
+    def OnChange(self, evt):
+        """Updates the text control using our custom stylings after
+        the font is changed.
+        @param evt: The event that called this handler
+
+        """
+        font = evt.GetFont()
+        self._font = font
+        self._text.Clear()
+        self._text.SetFont(self._font)
+        self._text.SetValue(u"%s - %dpt" % (font.GetFaceName(), \
+                                            font.GetPointSize()))
+        evt = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY, 
+                                         self.GetId(), self._font, self)
+        wx.PostEvent(self.GetParent(), evt)
+
+    def SetButtonLabel(self, label):
+        """Sets the buttons label"""
+        self._button.SetLabel(label)
+        self._button.Refresh()
+
+    def SetToolTip(self, tip):
+        """Sets the tooltip of the window
+        @param tip: wx.ToolTip
+
+        """
+        # Need to make copies of the tooltip or the program
+        # will crash when the dialog is closed and is doing cleanup
+        self._text.SetToolTip(tip)
+        tip = wx.ToolTip(tip.GetTip())
+        self._button.SetToolTip(tip)
+        tip = wx.ToolTip(tip.GetTip())
+        wx.Panel.SetToolTip(self, tip)
