@@ -35,8 +35,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: style_editor.py 283 2007-07-11 09:29:22Z CodyPrecord $"
-__revision__ = "$Revision: 283 $"
+__svnid__ = "$Id: style_editor.py 313 2007-07-22 04:08:27Z CodyPrecord $"
+__revision__ = "$Revision: 313 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -45,6 +45,7 @@ import glob
 import wx
 import wx.lib.colourselect as  csel
 import ed_glob
+from profiler import Profile_Get
 import ed_stc
 from ed_style import StyleItem
 import util
@@ -70,14 +71,22 @@ SETTINGS_IDS = [ ID_FORE_COLOR, ID_BACK_COLOR, ID_BOLD, ID_ITALIC,
 
 class StyleEditor(wx.Dialog):
     """This class creates the window that contains the controls
-    for editing/configuring the syntax highlighting styles.
+    for editing/configuring the syntax highlighting styles it acts
+    as a a graphical way to interact with the L{ed_style.StyleMgr}.
 
+    @see: ed_style.StyleMgr
     """
     def __init__(self, parent, id_=wx.ID_ANY, title=_("Style Editor"),
                  style=wx.DEFAULT_DIALOG_STYLE | wx.RAISED_BORDER):
-        """Initializes the Dialog"""
+        """Initializes the Dialog
+        @todo: rework the layout
+
+        """
         wx.Dialog.__init__(self, parent, id_, title, style=style)
 
+        if wx.Platform == '__WXMAC__' and Profile_Get('METAL', 'bool', False):
+            self.SetExtraStyle(wx.DIALOG_EX_METAL)
+
         # Attributes
         self.LOG = wx.GetApp().GetLog()
         self.preview = ed_stc.EDSTC(self, wx.ID_ANY, size=(-1, 200),
@@ -312,7 +321,7 @@ class StyleEditor(wx.Dialog):
         fground_sizer = wx.BoxSizer(wx.HORIZONTAL)
         fground_lbl = wx.StaticText(self.ctrl_pane, 
                                     label=_("Foreground") + u": ")
-        fground_sel = csel.ColourSelect(self.ctrl_pane, ID_FORE_COLOR, 
+        fground_sel = csel.ColourSelect(self.ctrl_pane, ID_FORE_COLOR,
                                         "#000000", (0, 0, 0), size=(80, 25))
         fground_sizer.AddMany([((5, 5)), 
                                (fground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
@@ -356,12 +365,12 @@ class StyleEditor(wx.Dialog):
         fsizer = wx.BoxSizer(wx.HORIZONTAL)
         flbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Font") + u": ")
         fontenum = wx.FontEnumerator()
-        fontenum.EnumerateFacenames(fixedWidthOnly = True)
+        fontenum.EnumerateFacenames(fixedWidthOnly=True)
         f_lst = fontenum.GetFacenames()
         f_lst.sort()
-        font_lst = ["%(helv)s", "%(mono)s", "%(other)s", "%(times)s"]
+        font_lst = ["%(primary)s", "%(secondary)s"]
         font_lst.extend(f_lst)
-        fchoice = wx.Choice(self.ctrl_pane, ID_FONT, choices = font_lst)
+        fchoice = wx.Choice(self.ctrl_pane, ID_FONT, choices=font_lst)
         fsizer.AddMany([((5, 5)), (flbl, 0, wx.ALIGN_CENTER_VERTICAL),
                         (fchoice, 0, wx.ALIGN_CENTER_VERTICAL), ((5, 5))])
         fbox_sizer.Add(fsizer, 0, wx.ALIGN_LEFT)
@@ -399,7 +408,7 @@ class StyleEditor(wx.Dialog):
         ss_lst.sort()
         ss_choice = wx.Choice(self.ctrl_pane, ed_glob.ID_PREF_SYNTHEME,
                               choices=ss_lst)
-        ss_choice.SetStringSelection(ed_glob.PROFILE['SYNTHEME'])
+        ss_choice.SetStringSelection(Profile_Get('SYNTHEME', 'str'))
         ss_new = wx.CheckBox(self.ctrl_pane, wx.ID_NEW, _("New"))
         ss_sizer.AddMany([((10, 10)), (ss_lbl, 0, wx.ALIGN_CENTER_VERTICAL), 
                           ((5, 0)),
@@ -474,9 +483,10 @@ class StyleEditor(wx.Dialog):
         if e_id == ed_glob.ID_LEXER:
             self.OpenPreviewFile(val)
         elif e_id == ed_glob.ID_PREF_SYNTHEME:
+            # TODO Need to check for style changes before switching this
             self.preview.UpdateAllStyles(val)
             self.styles_new = self.preview.GetStyleSet()
-            self.styles_orig = self.DuplicateStyleDict(self.styles_orig)
+            self.styles_orig = self.DuplicateStyleDict(self.styles_new)
             ctrl = self.FindWindowById(ID_STYLES)
             tag = ctrl.GetStringSelection()
             if tag != wx.EmptyString:
@@ -507,13 +517,9 @@ class StyleEditor(wx.Dialog):
         hex_str = "#%s%s%s" % (red[2:].zfill(2).upper(),
                                green[2:].zfill(2).upper(),
                                blue[2:].zfill(2).upper())
-        # ?wxBug? Label doesnt refresh unless I do this stupid sequence (wxMac)
-        e_obj.SetValue(wx.Color(e_val[0], e_val[1], e_val[2]))
         e_obj.SetLabel(hex_str)
-        e_obj.Refresh()
-        e_obj.Update()
         e_obj.SetValue(wx.Color(e_val[0], e_val[1], e_val[2]))
-        e_obj.SetLabel(hex_str)
+
         # Update The Style data for current tag
         self.UpdateStyleSet(e_id)
 
@@ -632,19 +638,12 @@ class StyleEditor(wx.Dialog):
             elif c_type == "wxChoice":
                 ctrl.SetStringSelection(val_map[sid])
             elif c_type == "wxBitmapButton":
+                # Note: must call set label before set value or the label
+                # is not redrawn
+                ctrl.SetLabel(val_map[sid][:7])
                 ctrl.SetValue(wx.Color(int(val_map[sid][1:3], 16), 
                                        int(val_map[sid][3:5], 16), 
                                        int(val_map[sid][5:7], 16)))
-                ctrl.SetLabel(val_map[sid][:7])
-                # HACK the button refuses to update rightaway unless I do this 
-                #      in this order. wxMac: ?Bug?
-                ctrl.Refresh()
-                ctrl.Update()
-                ctrl.SetValue(wx.Color(int(val_map[sid][1:3], 16), 
-                                       int(val_map[sid][3:5], 16), 
-                                       int(val_map[sid][5:7], 16)))
-                ctrl.SetLabel(val_map[sid][:7])
-
         return True
 
     def UpdateStyleSet(self, id_):
